Coverage for curator/actions/__init__.py: 100%

1"""Use __init__ to make these not need to be nested under lowercase.Capital"""

2 from curator.actions.alias import Alias

3 from curator.actions.allocation import Allocation

4 from curator.actions.close import Close

5 from curator.actions.cluster_routing import ClusterRouting

6 from curator.actions.cold2frozen import Cold2Frozen

7 from curator.actions.create_index import CreateIndex

8 from curator.actions.delete_indices import DeleteIndices

9 from curator.actions.forcemerge import ForceMerge

10 from curator.actions.index_settings import IndexSettings

11 from curator.actions.open import Open

12 from curator.actions.reindex import Reindex

13 from curator.actions.replicas import Replicas

14 from curator.actions.rollover import Rollover

15 from curator.actions.shrink import Shrink

16 from curator.actions.snapshot import Snapshot, DeleteSnapshots, Restore

17

18 CLASS_MAP = {

19 'alias' : Alias,

20 'allocation' : Allocation,

21 'close' : Close,

22 'cluster_routing' : ClusterRouting,

23 'cold2frozen': Cold2Frozen,

24 'create_index' : CreateIndex,

25 'delete_indices' : DeleteIndices,

26 'delete_snapshots' : DeleteSnapshots,

27 'forcemerge' : ForceMerge,

28 'index_settings' : IndexSettings,

29 'open' : Open,

30 'reindex' : Reindex,

31 'replicas' : Replicas,

32 'restore' : Restore,

33 'rollover' : Rollover,

34 'snapshot' : Snapshot,

35 'shrink' : Shrink,

36}